from setuptools import setup, find_packages


setup(
    name="lib_for_messanger",
    version="0.4",
    description="library for my messenger",
    url="https://github.com/VPG1/lib_for_messanger",
    author="Kirill Malihtorovich",
    author_email="mmalihtorovic@gmail.com",
    classifiers=[
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3.10",
        "Operating System :: OS Independent"
    ],
    packages=["lib_for_messanger"]
)
